@@ -9,7 +9,7 @@
 #include "globalcontactmodel.h"
 
 #include <Akonadi/ChangeRecorder>
-#include <Akonadi/Contact/ContactsTreeModel>
+#include <Akonadi/ContactsTreeModel>
 #include <Akonadi/EntityDisplayAttribute>
 #include <Akonadi/ItemFetchScope>
 #include <Akonadi/Session>
@@ -20,14 +20,14 @@
 GlobalContactModel *GlobalContactModel::mInstance = nullptr;
 
 GlobalContactModel::GlobalContactModel()
+    : mSession(new Akonadi::Session("KAddressBook::GlobalContactSession"))
+    , mMonitor(new Akonadi::ChangeRecorder)
 {
-    mSession = new Akonadi::Session("KAddressBook::GlobalContactSession");
 
     Akonadi::ItemFetchScope scope;
     scope.fetchFullPayload(true);
     scope.fetchAttribute<Akonadi::EntityDisplayAttribute>();
 
-    mMonitor = new Akonadi::ChangeRecorder;
     mMonitor->setSession(mSession);
     mMonitor->fetchCollection(true);
     mMonitor->setItemFetchScope(scope);
