@@ -1,14 +1,13 @@
 /*
   This file is part of KAddressBook.
 
-  SPDX-FileCopyrightText: 2009-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2009-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "kaddressbookpart.h"
-#include <kcoreaddons_version.h>
-#if KCOREADDONS_VERSION < QT_VERSION_CHECK(6, 0, 0)
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
 #include "kaddressbookmigrateapplication.h"
 #endif
 #include "mainwidget.h"
@@ -28,7 +27,7 @@ KAddressBookPart::KAddressBookPart(QWidget *parentWidget, QObject *parent, const
     : KParts::Part(parent)
 {
     setComponentName(QStringLiteral("kaddressbook"), i18n("KAddressBook"));
-#if KCOREADDONS_VERSION < QT_VERSION_CHECK(6, 0, 0)
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     KAddressBookMigrateApplication migrate;
     migrate.migrate();
 #endif
@@ -69,9 +68,7 @@ void KAddressBookPart::newGroup()
     mMainWidget->newGroup();
 }
 
-KAddressBookPart::~KAddressBookPart()
-{
-}
+KAddressBookPart::~KAddressBookPart() = default;
 
 void KAddressBookPart::guiActivateEvent(KParts::GUIActivateEvent *e)
 {
